@@ -1,6 +1,12 @@
 class simpleobject(dict):
     '''Simple json serializable object'''
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        for key, value in tuple(self.items()):
+            if issubclass(type(value), dict):
+                self[key] = simpleobject(value)
+
     def __str__(self):
         name_key = '__name__' if '__name__' in self else 'name' if 'name' in self else None
         name = self[name_key] if name_key in self else 'simpleobject'
